#!/usr/bin/env python

# MIT License
# Copyright (c) 2021 Aahnik Daw

import os

from enum import Enum


class Position(str,Enum):
    top_left = "10:10"
    top_right = "W-w-10:10"
    centre = "(W-w)/2:(H-h)/2"
    bottom_left = "10:H-h-10"
    bottom_right = "W-w-10:H-h-10"


class File:
    def __init__(self, path):
        self.path = path
        self.type = self.find_type()

    def find_type(self):
        ext = self.path.split(".")[-1]
        if ext in ["png", "jpeg", "jpg"]:
            return "image"
        elif ext in ["mp4", "gif"]:
            return "video"
        else:
            raise Exception(f"File type {ext} not supported.")


class Watermark:
    def __init__(
        self,
        overlay: File,
        pos: str = Position.centre,
    ):
        self.overlay = overlay
        self.pos = pos


def apply_watermark(
    file: File,
    wtm: Watermark,
    output_file: str = "",
    frame_rate: int = 15,
    preset: str = "ultrafast",
) -> str:

    if not output_file:
        output_file = f"watered_{file.path}"

    command = f'ffmpeg -i {file.path} \
        -i {wtm.overlay.path} \
        -an -dn -sn -r {frame_rate} \
        -preset {preset} \
        -tune zerolatency  -tune fastdecode \
        -filter_complex "overlay={wtm.pos}" \
        {output_file}'

    print(f"Running command {command}")
    os.system(command)
    return output_file



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['watermark']
setup_kwargs = {
    'name': 'watermark.py',
    'version': '0.0.2rc1',
    'description': 'A convinient python wrapper around ffmpeg to apply watermarks to images, gifs and videos.',
    'long_description': '# watermark.py\n\nA convinient python wrapper around `ffmpeg` to apply\nwatermarks to images, gifs and videos.\n\n## Installation\n\n```shell\npip install watermark.py\n```\n\nYou need to install  [`ffmpeg`](https://ffmpeg.org/) seperately.\n\n## Usage\n\n<!-- ### GUI\n\nVisit watermark.py.aahnik.dev to experience the web app.\n\n### CLI\n\nYou can use the command-line interface to easily apply watermark.\n\n```shell\nwatermark --help\n``` -->\n\n<!-- ### Python -->\n\n```python\nfrom watermark import File, Watermark, apply_watermark\n\nvideo = File("vid.mp4")\nwatermark = Watermark("im.png")\n\napply_watermark(video, watermark)\n```\n\n<!-- ## Used by\n\n- tgcf\n- telewater -->\n',
    'author': 'aahnik',
    'author_email': 'daw@aahnik.dev',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aahnik/watermark.py',
    'py_modules': modules,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
